@@ -1,7 +1,3 @@
-"""
-interface
----------
-"""
 from collections import defaultdict
 from operator import attrgetter, itemgetter
 from textwrap import dedent
@@ -35,6 +31,8 @@ CLASS_ATTRIBUTE_WHITELIST = frozenset([
 
 is_interface_field_name = complement(CLASS_ATTRIBUTE_WHITELIST.__contains__)
 
+TRIVIAL_CLASS_ATTRIBUTES = frozenset(dir(type('_', (object,), {})))
+
 
 def static_get_type_attr(t, name):
     """
@@ -263,10 +261,92 @@ class InterfaceMeta(type):
 class Interface(with_metaclass(InterfaceMeta)):
     """
     Base class for interface definitions.
+
+    An interface defines a set of methods and/or attributes that should be
+    provided by one or more classes, which are called "implementations" of the
+    interface.
+
+    Classes can declare that they implement an interface ``I`` by subclassing
+    ``implements(I)``. During class construction, the base class generated by
+    ``implements(I)`` will verify that the new class correctly implements all
+    the methods required  by ``I``.
+
+    Interfaces cannot be instantiated.
+
+    Examples
+    --------
+
+    **Defining an Interface:**
+
+    .. code-block:: python
+
+        class KeyValueStore(Interface):
+
+            def get(self, key):
+                pass
+
+            def set(self, key, value):
+                pass
+
+            def delete(self, key):
+                pass
+
+    **Implementing an Interface:**
+
+    .. code-block:: python
+
+        class InMemoryKeyValueStore(implements(KeyValueStore)):
+
+            def __init__(self):
+                self.data = {}
+
+            def get(self, key):
+                return self.data[key]
+
+            def set(self, key, value):
+                self.data[key] = value
+
+            def delete(self, key):
+                del self.data[key]
+    See Also
+    --------
+    :func:`implements`
     """
     def __new__(cls, *args, **kwargs):
         raise TypeError("Can't instantiate interface %s" % getname(cls))
 
+    @classmethod
+    def from_class(cls, existing_class, subset=None, name=None):
+        """Create an interface from an existing class.
+
+        Parameters
+        ----------
+        existing_class : type
+            The type from which to extract an interface.
+        subset : list[str], optional
+            List of methods that should be included in the interface.
+            Default is to use all attributes not defined in an empty class.
+        name : str, optional
+            Name of the generated interface.
+            Default is ``existing_class.__name__ + 'Interface'``.
+
+        Returns
+        -------
+        interface : type
+            A new interface class with stubs generated from ``existing_class``.
+        """
+        if name is None:
+            name = existing_class.__name__ + 'Interface'
+
+        if subset is None:
+            subset = set(dir(existing_class)) - TRIVIAL_CLASS_ATTRIBUTES
+
+        return InterfaceMeta(
+            name,
+            (Interface,),
+            {name: static_get_type_attr(existing_class, name) for name in subset},
+        )
+
 
 empty_set = frozenset([])
 
@@ -345,17 +425,57 @@ def _make_implements():
 
     def implements(*interfaces):
         """
-        Make a base for classes that implement ``*interfaces``.
+        Make a base for a class that implements one or more interfaces.
 
         Parameters
         ----------
-        I : Interface
+        *interfaces : tuple
+            One or more subclasses of :class:`~interface.Interface`.
 
         Returns
         -------
         base : type
             A type validating that subclasses must implement all interface
-            methods of I.
+            methods of types in ``interfaces``.
+
+        Examples
+        --------
+        **Implementing an Interface:**
+
+        .. code-block:: python
+
+            class MyInterface(Interface):
+                 def method1(self, x):
+                     pass
+
+                 def method2(self, y):
+                     pass
+
+            class MyImplementation(implements(MyInterface)):
+                 def method1(self, x):
+                     return x + 1
+
+                 def method2(self, y):
+                     return y * 2
+
+        **Implementing Multiple Interfaces:**
+
+        .. code-block:: python
+
+            class I1(Interface):
+                def method1(self, x):
+                    pass
+
+            class I2(Interface):
+                def method2(self, y):
+                    pass
+
+            class ImplBoth(implements(I1, I2)):
+                def method1(self, x):
+                    return x + 1
+
+                def method2(self, y):
+                    return y * 2
         """
         if not interfaces:
             raise TypeError("implements() requires at least one interface")
